@@ -1,4 +1,4 @@
-__version__ = "0.1.7"
+__version__ = "0.1.8"
 __keywords__ = ["python cgi apache stream file cache server proxy http cors"]
 
 
@@ -16,6 +16,6 @@ from .core import (
     execute, print, print_file, flush, main,
     log, log_construct,
     should_return_304,
-    basic_authorization, parse_authorization,
+    basic_authorization, parse_authorization, set_authenticate_response,
 )
 
