@@ -283,15 +283,18 @@ def _basic_authorization(credentials: dict = None):
     if not credentials:
         credentials = {"admin": "admin"}
     if "Authorization" not in _HEADERS:
-        set_status(401)
-        set_header("WWW-Authenticate", "Basic")
+        set_authenticate_response()
         return False
     u, p = parse_authorization()
     if u in credentials and credentials[u] == p:
         return True
+    set_authenticate_response()
+    return False
+
+
+def set_authenticate_response():
     set_status(401)
     set_header("WWW-Authenticate", "Basic")
-    return False
 
 
 def parse_authorization():
