@@ -5,7 +5,7 @@ from pythoncgi import (
     execute, print, print_file, flush, main,
     log, log_construct,
     should_return_304,
-    basic_authorization, parse_authorization,
+    basic_authorization, parse_authorization, set_authenticate_response,
 )
 import os
 
